<?php

function alignment_info() {
  $object = new StdClass();

  $object->name     = t('Alignment');
  $object->author   = 'Morbus Iff';
  $object->email    = 'morbus@disobey.com';
  $object->url      = 'http://www.gamegrene.com/forum/53';
  $object->modified = '2006-03-08';
  $object->version  = 0.2;

  $object->description_short = t('Whether it\'s a complex system of varying degrees or just a blanket Good and Evil, most game systems have some sort of "alignment" metric to indicate just how strong your character leans from the comforting center of neutrality. This plugin implements a rather basic approach of Good, Bad, Ugly, and So-So. It also serves as an example of how to add more choices during character creation.');
  $object->description_long  = "<p>$object->description_short</p>";

  return $object;
}

/**
 * Drupal's hook_form_alter() allows any module (and, via the GameAPI, any
 * include) to modify forms before they're displayed to the user. Here, we're
 * adding our "Alignment" select to the character creation screens.
 */
function alignment_drupal_form_alter($form_id, $form) {
  if ($form_id == 'game_character_node_form') {
    $alignment = game_mob_get('_character', 'general', 'alignment');

    $form['mental']['alignment'] = array(
      '#required'      => TRUE,
      '#type'          => 'select',
      '#title'         => t('Alignment'),
      '#description'   => t("Your character's ethical and moral perspective."),
      '#options'       => array('good' => t('The Good'), 'bad' => t('The Bad'), 'ugly' => t('The Ugly'), 'so-so' => t('The So-so')),
      '#default_value' => isset($alignment) ? $alignment : 'good',
    );
  }
  return $form;
}

/**
 * Drupal's hook_insert() is called whenever a game character is created.
 * Since the default functions don't know about our alignment, we manually
 * set the alignment for this character, which will get automatically loaded
 * during Drupal's hook_load() (thus we don't need to define our own).
 */
function alignment_drupal_insert($node) {
  game_mob_set('_character', 'general', 'alignment', $node->alignment);
}

/**
 * Most character information, such as statistics or race, aren't allowed to
 * be changed by the player after character creation. Alignment, however, is
 * a state of mind, and a character can change over their lives. So, we use
 * Drupal's hook_update() to catch any player changes to their character.
 */
function alignment_drupal_update($node) {
  game_mob_set('_character', 'general', 'alignment', $node->alignment);
}

/**
 * Alignment is shown as a "character fact" on node views.
 */
function alignment_game_character_node_facts($node) {
  $alignment = game_mob_get('_character', 'general', 'alignment');
  return array(t('%name is of %alignment alignment.', array('%name' => $node->title, '%alignment' => $alignment)));
}
