<?php

function engine_info() {
  $object = new StdClass();

  $object->name     = t('Default Engine');
  $object->author   = 'Morbus Iff';
  $object->email    = 'morbus@disobey.com';
  $object->url      = 'http://www.gamegrene.com/forum/53';
  $object->modified = '2006-01-24';
  $object->version  = 0.1;

  $object->description_short = t('(REQUIRED) This is the default engine for the GameAPI - it contains the standard rules, values, attributes, etc., needed to get the game running based on the default game world data. Advanced users may change this as they see fit, of course, but be wary that the changes may make third party world data incompatible (like depending on a "Strength" attribute that no longer exists) or simply unbalanced. Don\'t hesitate to share any changes!');
  $object->description_long  = "<p>$object->description_short</p>";

  return $object;
}

/**
 * Default value for hook 'access'. We always allow by default.
 */
function engine_access_default($type) {
  return 1;
}

/**
 * These are the attributes for the default Game API implementation.
 */
function engine_attributes() {
  $attributes = array();

  // primary attributes.
  $attributes['agility'] = array(
      'name'          => t('Agility'),
      'group'         => 'primary',
      'default_value' => dice('3^4d6'),
      'abbreviation'  => 'AGI',
      'progression'   => dice('1d3'),
      'description'   => t("A measure of a character's physical dexterity and finesse."),
  );
  $attributes['charisma'] = array(
      'name'          => t('Charisma'),
      'group'         => 'primary',
      'default_value' => dice('3^4d6'),
      'abbreviation'  => 'CHA',
      'progression'   => dice('1d3'),
      'description'   => t("A measure of charm and influence exerted over others."),
  );
  $attributes['endurance'] = array(
      'name'          => t('Endurance'),
      'group'         => 'primary',
      'default_value' => dice('3^4d6'),
      'abbreviation'  => 'END',
      'progression'   => dice('1d3'),
      'description'   => t("A measure of physical health, stamina, and longevity."),
  );
  $attributes['intellect'] = array(
      'name'          => t('Intellect'),
      'group'         => 'primary',
      'default_value' => dice('3^4d6'),
      'abbreviation'  => 'INT',
      'progression'   => dice('1d3'),
      'description'   => t("A measure of a character's logical intelligence and memory."),
  );
  $attributes['strength'] = array(
      'name'          => t('Strength'),
      'group'         => 'primary',
      'default_value' => dice('3^4d6'),
      'abbreviation'  => 'STR',
      'progression'   => dice('1d3'),
      'description'   => t("A measure of a character's physical strength and brawn."),
  );
  $attributes['wisdom'] = array(
      'name'          => t('Wisdom'),
      'group'         => 'primary',
      'default_value' => dice('3^4d6'),
      'abbreviation'  => 'WIS',
      'progression'   => dice('1d3'),
      'description'   => t(" A measure of common sense and ability to determine truth."),
  );

  // secondary attributes.
  $attributes['ap'] = array(
      'name'          => t('Action Points'),
      'group'         => 'secondary',
      'default_value' => 40,
      'abbreviation'  => 'AP',
      'progression'   => 0,
      'description'   => t('Amount of character activity performable before resting.'),
  );
  $attributes['hp'] = array(
      'name'          => t('Hit Points'),
      'group'         => 'secondary',
      'default_value' => dice('3d10'),
      'abbreviation'  => 'HP',
      'progression'   => dice('1d3'),
      'description'   => t('The current health of the character.'),
  );
  $attributes['pp'] = array(
      'name'          => t('Power Points'),
      'group'         => 'secondary',
      'default_value' => dice('3d10'),
      'abbreviation'  => 'PP',
      'progression'   => dice('1d3'),
      'description'   => t('The current power capability of the character.'),
  );
  $attributes['xp'] = array(
      'name'          => t('Experience Points'),
      'group'         => 'secondary',
      'default_value' => 1,
      'abbreviation'  => 'XP',
      'progression'   => 0,
      'description'   => t("Experience gained during the character's journey."),
  );
  $attributes['level'] = array(
      'name'          => t('Level'),
      'group'         => 'secondary',
      'default_value' => 1,
      'abbreviation'  => 'LVL',
      'progression'   => 1,
      'description'   => t('A milestone represented by the number of experience points.'),
  );

  return $attributes;
}
