<?php

/**
 * info - Describes the data within your object (required).
 */
function example_info() {
  watchdog('gameapi debug', t('plugins/example.inc, info.'));

  $object = new StdClass();

  $object->name     = t('Example Plugin');
  $object->author   = 'Morbus Iff';
  $object->email    = 'morbus@disobey.com';
  $object->url      = 'http://www.gamegrene.com/forum/53';
  $object->modified = '2005-12-24';
  $object->version  = 0.1;

  $object->description_short = t('This plugin serves as a starting example for accessing all the various hooks of the GameAPI. Largely, it does this by spitting out debugging statements to the Drupal logs under the message type "gameapi debug". If you\'re looking for further concrete examples of how to use the GameAPI besides this plugin, check the API.php file. Most admins will want to disable this plugin before making their game public.');
  $object->description_long  = "<p>$object->description_short</p>";

  return $object;
}

/**
 * access - Determines who (player or character) can access your object.
 * Its use here demonstrates the structure of the default access mode.
 */
function example_access($type) {
  watchdog('gameapi debug', t('plugins/example.inc, access.'));

  switch($type) {
    case 'accessible by player':     return 1;
    case 'accessible by character':  return 1;
  }
}

/**
 * onInfo - Describes the data within your object.
 * This is an example of the onInfo hook, which is called after any info
 * hook. Here, we're just printing a log, modifying the version of the human
 * race, and then returning the result. In most cases, plugins will use onInfo
 * to add new data to the objects, and then act on it later.
 */
function example_onInfo($result, $include) {
  watchdog('gameapi debug', t('plugins/example.inc, onInfo, %include.', array('%include' => $include)));

  if ($include == 'human') {
    $result->version += 0.000002;
  }

  return $result;
}

/**
 * onAccess - Determines who (player or character) can access your object.
 * In this particular (fictional) example, we don't like the fact that the
 * (fictional) include "snowman baby" is, by default, hidden from player
 * view. We can simply reset that access to accessible (ie. 1).
 */
function example_onAccess($result, $include, $type) {
  watchdog('gameapi debug', t('plugins/example.inc, onAccess, %include.', array('%include' => $include)));

  if ($include == 'snowman_baby') {
    if ($type == 'accessible by player') {
      return 1;
    }
  }

  return $result;
}

/**
 * drupal_access - This hook controls operations in relation to the creation
 * and editing of a game_character node. This happens AFTER the standard Drupal
 * access check (via "admin > access control > create game characters") is
 * checked for TRUE (if FALSE, this hook is never called). Its primary use, as
 * demonstrated here, is to check against our player's previous history and
 * further determine if they can create new characters.
 */
function example_drupal_access($op, $node) {
  watchdog('gameapi debug', t('plugins/example.inc, drupal_access, %op.', array('%op' => $op)));
  global $user; // the user attempting to create a new character.

  if ($op == 'create') {

    // in this example, we limit the number of characters that a user can
    // create to 10. we'll return FALSE, but also set an error message.
    if (count(game_player_characters($user->uid)) >= 10) {
      drupal_set_message(t('You are only allowed 10 game characters.'), 'error');
      return FALSE;
    }

  }
}

/**
 * drupal_view - This hook allows plugins to append data to the existing "node
 * body" of the game character when accessed via a URL like node/1356. Unlike
 * the regular Drupal NodeAPI view, however, we only return the data that we'd
 * like appended to the existing body. Here, we're just including a useless
 * status message of how many character this player has.
 */
function example_drupal_view($node) {
  watchdog('gameapi debug', t('plugins/example.inc, drupal_view, %title.', array('%title' => $node->title)));

  $count = count(game_player_characters($node->uid));
  $user  = theme('username', user_load(array('uid' => $node->uid)));
  return '<p>'.t('This is 1 of %count characters that %user controls.', array('%count' => $count, '%user' => $user)).'</p>';
}
